@@ -40,7 +40,61 @@ class Browser(webdriver.Chrome):
     hide (True default): esconde a janela
     clean (True default): limpa o cache da janela
     """
-    
+    @classmethod
+    def clear_cache(self):
+        # opening clear browse data page
+        self.get('chrome://settings/clearBrowserData')
+        # find time range dropdown. Full xpath:
+        # /html/body/# settings-ui//div[2]/settings-main//settings-basic-page//div[1]/settings-section[4]/settings-privacy-page
+        # //# settings-clear-browsing-data-dialog//cr-dialog[1]/div[3]/iron-pages/div[2]/div/settings-dropdown-menu//select'
+        try:
+            self.__root1 = Browser.find_element_by_tag_name("settings-ui")
+            self.__shadow_root1 = self.__expand_shadow_element(Browser, self.__root1)
+            self.__root2 = self.__shadow_root1.find_element_by_css_selector("settings-main#main")
+            self.__shadow_root2 = self.__expand_shadow_element(Browser, self.__root2)
+            self.__root3 = self.__shadow_root2.find_element_by_css_selector("settings-basic-page[role='main']")
+            self.__shadow_root3 = self.__expand_shadow_element(Browser, self.__root3)
+            self.__webelement1 = self.__shadow_root3.find_element_by_css_selector("settings-section[page-title='Privacy and security']")
+            self.__root4 = self.__webelement1.find_element_by_css_selector('settings-privacy-page')
+            self.__shadow_root4 = self.__expand_shadow_element(Browser, self.__root4)
+            time.sleep(1)
+            self.__root5 = self.__shadow_root4.find_element_by_css_selector('settings-clear-browsing-data-dialog')
+            self.__shadow_root5 = self.__expand_shadow_element(Browser, self.__root5)
+            self.__root6 = self.__shadow_root5.find_element_by_id('clearBrowsingDataDialog')
+            self.__webelement2 = self.__root6.find_element_by_id('clearFromBasic')
+            self.__shadow_root6 = self.__expand_shadow_element(Browser, self.__webelement2)
+            self.__dropdown = Select(self.__shadow_root6.find_element_by_id('dropdownMenu'))
+            #select option all time
+            self.__dropdown.select_by_visible_text('All time')
+            """
+            #wait for button Clear Data Button to appear
+            try:
+                while not self.__root6.find_element_by_id('clearBrowsingDataConfirm'):
+                    pass
+            except exceptions.StaleElementReferenceException:
+                raise Sair
+            """
+           # click button
+            self.__button = self.__root6.find_element_by_id('clearBrowsingDataConfirm')
+            self.__button.click()
+            # wait until button disapears
+            try:
+                while self.__button.is_displayed():
+                    pass
+            except exceptions.StaleElementReferenceException:
+                if Browser.current_url == 'chrome://settings/':
+                    pass
+                else:
+                    raise Sair
+
+        except Exception as e:
+            if e.args[0] == 'name \'Sair\' is not defined':
+                pass
+            else:
+                raise NameError('Ocorreu um problema')
+
+
+
     @classmethod
     def unhide(self):
         self.set_window_position(0, 0)
